@@ -3,4 +3,4 @@ from bond.database import BondDatabase
 def test_database_get_and_set():
   for i in range(5):
     BondDatabase.set("test", i)
-    assert BondDatabase.get("test") == i
\ No newline at end of file
+    assert BondDatabase().get("test") == i
\ No newline at end of file
